==> xplr-0.5.9.crate: xplr-0.5.9/README.md <==
<h1 align="center">xplr</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr" target="_blank">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://discord.gg/p8UPpgAx" target="_blank">
<img src="https://img.shields.io/discord/834369918312382485?logo=discord&style=social" />
</a>

</p>

<p align="center">
<img src="https://s3.gifyu.com/images/xplr-0.5.0.gif" />
</p>

Though [xplr](https://github.com/sayanarijit/xplr) strives to be fast and minimalist, its speciality is its hackability.

Once you read the [documentation](https://github.com/sayanarijit/xplr/wiki), you should be able to configure the key bindings,
different run modes, and also the way it looks by modifying one single configuration file.


- ### [Quickstart](https://github.com/sayanarijit/xplr/wiki/Quickstart)

- ### [Features](https://github.com/sayanarijit/xplr/wiki/Features)

- ### [Plugins](https://github.com/sayanarijit/xplr/wiki/Plugins)

- ### [Hacks](https://github.com/sayanarijit/xplr/wiki/Hacks)

- ### [Themes](https://github.com/sayanarijit/xplr/wiki/Themes)

- ### [TODO](https://github.com/sayanarijit/xplr/wiki/TODO)

- ### [Upgrade Guide](https://github.com/sayanarijit/xplr/wiki/Upgrade-Guide)

- ### [Alternatives](https://github.com/sayanarijit/xplr/wiki/Alternatives)


## Demo

<p align="center">

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#fuzzy-search-with-preview" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-fzf.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#batch-rename" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-rename.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#serve-pwd" target="_blank">
<img height=240 width=360 src="https://s3.gifyu.com/images/xplr-serve.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#disk-usage-dua-cli" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-dua.gif" />
</a>

</p>

## Packaging

[![Packaging status](https://repology.org/badge/vertical-allrepos/xplr.svg)](https://repology.org/project/xplr/versions)

## Backers

<a href="https://opencollective.com/xplr#backer"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>

==> xplr-0.8.4.crate: xplr-0.8.4/README.md <==
<h1 align="center">
  ▸[<a href="https://github.com/sayanarijit/xplr/blob/main/assets/icon/xplr.svg" target="_blank"><img src="https://s3.gifyu.com/images/xplr32.png" alt="▓▓" height="20" width="20" /></a> xplr]
</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr" target="_blank">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://discord.gg/p8UPpgAx" target="_blank">
<img src="https://img.shields.io/discord/834369918312382485?logo=discord&style=social" />
</a>

</p>

<p align="center">
<img src="https://s3.gifyu.com/images/xplr-0.5.0.gif" />
</p>

Though [xplr](https://github.com/sayanarijit/xplr) strives to be fast and minimalist, its speciality is its hackability.

Once you read the [documentation](https://github.com/sayanarijit/xplr/wiki), you should be able to configure the key bindings,
different run modes, and also the way it looks by modifying one single configuration file.


Table of content
----------------

- ### [Quickstart](https://github.com/sayanarijit/xplr/wiki/Quickstart)

- ### [Features](https://github.com/sayanarijit/xplr/wiki/Features)

- ### [Plugins](https://github.com/sayanarijit/xplr/wiki/Plugins)

- ### [Hacks](https://github.com/sayanarijit/xplr/wiki/Hacks)

- ### [Themes](https://github.com/sayanarijit/xplr/wiki/Themes)

- ### [TODO](https://github.com/sayanarijit/xplr/wiki/TODO)

- ### [Upgrade Guide](https://github.com/sayanarijit/xplr/wiki/Upgrade-Guide)

- ### [Alternatives](https://github.com/sayanarijit/xplr/wiki/Alternatives)

- ### [Community](https://github.com/sayanarijit/xplr/wiki/Community)

- ### [Contribute](https://github.com/sayanarijit/xplr/wiki/Contribute)


## Demo

<p align="center">

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#fuzzy-search-with-preview" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-fzf.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#batch-rename" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-rename.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#serve-pwd" target="_blank">
<img height=240 width=360 src="https://s3.gifyu.com/images/xplr-serve.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Themes#material-landscape" target="_blank">
<img height=240 width=360 src="https://s3.gifyu.com/images/theaming.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#sendreceive-files-via-qr-code-on-lan" target="_blank">
<img height=240 width=360 src="https://s4.gifyu.com/images/xplr-qr.gif" />
</a>

<a href="https://github.com/sayanarijit/xplr/wiki/Hacks#spawn-multiple-sessions-in-different-windows" target="_blank">
<img height=240 width=360 src="https://s3.gifyu.com/images/xplr-sessions.gif" />
</a>

</p>

## Packaging

<a href="https://repology.org/project/xplr/versions" target="_blank"><img src="https://repology.org/badge/vertical-allrepos/xplr.svg" /></a>

## Backers

<a href="https://opencollective.com/xplr#backer" target="_blank"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>
